import argparse
from pinellm.config.config_manager import ConfigManager

__version__ = """
PineLLm v1.0.5
"""

def main():
    parser = argparse.ArgumentParser(
        description="Pinellm 命令行工具",
        add_help=False
    )
    parser.add_argument(
        "-h", "--help", # 允许没有参数
        help="显示帮助信息",
        action="help"
    )

    parser.add_argument(
        "-v", "--version", # 允许没有参数
        help="显示版本信息",
        action="version",
        version=__version__
    )
    
    parser.add_argument(
        "-s", "--supplier",
        nargs='?',  # 允许可选参数（参数可有可无）
        const="list",  # 如果未提供参数值，则默认为 "list"
        help="供应商操作："
            "- 不带参数或 `list`：列出所有供应商；"
            "- 指定名称（如 `qwen`）：显示该供应商详情"
    )
    
    parser.add_argument(
        "-m", "--model",
        nargs='?',  # 允许可选参数（参数可有可无）
        const="list",  # 如果未提供参数值，则默认为 "list"
        help="供应商操作："
            "- 不带参数或 `list`：列出所有模型；"
            "- 指定名称（如 `glm-4-plus`）：显示该模型详情"
    )
    try:
        args = parser.parse_args()

        config_manager = ConfigManager()
        
        if args.supplier:
            suppliers = config_manager.Supplier_Map.to_dict()
            if args.supplier == "list": 
                print("供应商列表:")
                for suppliersname in suppliers.keys():
                    if suppliersname == "_template":
                        continue
                    print(f"- {suppliersname}")
            else:
                try:
                    suppliersinfo = suppliers[args.supplier]
                except KeyError:
                    print(f"供应商【{args.supplier}】不存在")
                    exit(1)
                print(f"供应商【{args.supplier}】的基本信息:")
                print(f"- 名称: {suppliersinfo.get('name')}")
                print(f"- 描述: {suppliersinfo.get('description')}")
                print(f"- 基础URL: {suppliersinfo.get('url')}")
                print(f"- 支持模型: {suppliersinfo.get('models')}")
                print(f"- 嵌入模型: {suppliersinfo.get('emb_models')}") if suppliersinfo.get('emb_models') else None
                print(f"- 嵌入URL: {suppliersinfo.get('emb_url')}") if suppliersinfo.get('emb_url') else None
        
        elif args.model:
            models = config_manager.Model_Map.to_dict()
            if args.model == "list":
                print("模型列表:")
                for modelname in models.keys():
                    if modelname == "_template":
                        continue
                    print(f"- {modelname}")
            else:
                try:
                    modelinfo = models[args.model]
                except KeyError:
                    print(f"模型【{args.model}】不存在")
                    exit(1)
                print(f"模型【{args.model}】的基本信息:")
                print(f"- 供应商: {modelinfo.get('supplier')}") if modelinfo.get('supplier') else None
                print(f"- 描述: {modelinfo.get('description')}") if modelinfo.get('description') else None
                print(f"- 最新版: {modelinfo.get('newname')}")  if modelinfo.get('newname') else None
                print(f"- 稳定版: {modelinfo.get('name')}") if modelinfo.get('name') else None
                print(f"- 输出价格: {modelinfo.get('price_out')} / 千token") if modelinfo.get('price_out') else None
                print(f"- 输入价格: {modelinfo.get('price_in')} / 千token") if modelinfo.get('price_in') else None
                print(f"- 最大输入: {modelinfo.get('max_tokens_in')} TOKEN") if modelinfo.get('max_tokens_in') else None
                print(f"- 最大输出: {modelinfo.get('max_tokens_out')} TOKEN") if modelinfo.get('max_tokens_out') else None
                print(f"- 思维链长度: {modelinfo.get('max_thought')} TOKEN") if modelinfo.get('max_thought') else None
                print(f"- 最大上下文: {modelinfo.get('max_context')} TOKEN") if modelinfo.get('max_context') else None
                print(f"- 内置搜索: 支持") if modelinfo.get('enable_search') else None
                print(f"- 工具调用: 支持") if modelinfo.get('tools') else None
                print(f"- 文字输入: 支持") if modelinfo.get('text_input') else None
                print(f"- 文字输出: 支持") if modelinfo.get('text_output') else None
                print(f"- 图片输入: 支持") if modelinfo.get('image_input') else None
                print(f"- 图片输出: 支持") if modelinfo.get('image_output') else None
                print(f"- 音频输入: 支持") if modelinfo.get('audio_input') else None
                print(f"- 音频输出: 支持") if modelinfo.get('audio_output') else None
                print(f"- 视频输入: 支持") if modelinfo.get('video_input') else None
                print(f"- 视频输出: 支持") if modelinfo.get('video_output') else None
                print(f"- 推理链: 支持") if modelinfo.get('thought_chain') else None
        
        elif args.version:
            print("版本信息:")
            print(f"- 当前版本: {__version__}")
    except Exception as e:
        print("参数错误")
        
if __name__ == "__main__":
    main()